import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, Component, NgModule } from '@angular/core';
import * as i2$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i1 from '@ngrx/store';
import { createAction, createFeature, createReducer, on, createSelector, StoreModule } from '@ngrx/store';
import { createPayloadAction } from 'imng-ngrx-utils';
import * as i2 from '@ngrx/effects';
import { createEffect, EffectsModule } from '@ngrx/effects';
import { switchMap, filter, map, tap } from 'rxjs/operators';
import { timer, BehaviorSubject, interval } from 'rxjs';
import { oidcFeature } from 'imng-oidc-client';
import * as i3 from '@progress/kendo-angular-dialog';
import { DialogModule } from '@progress/kendo-angular-dialog';
import * as i4 from '@progress/kendo-angular-buttons';
import { ButtonsModule } from '@progress/kendo-angular-buttons';

const onSessionExtended = createAction('[Idle] Session Extended');
const onSessionTimingOut = createPayloadAction('[Idle] Session Timing Out');
const signOutRedirect = createAction('[Oidc] sign out redirect');

const IDLE_FEATURE_KEY = 'idle';
const initialState = {
    isTimingOut: false,
    timeoutSpanInMs: undefined,
};
const idleFeature = createFeature({
    name: IDLE_FEATURE_KEY,
    reducer: createReducer(initialState, on(onSessionTimingOut, (state, { payload }) => ({
        ...state,
        isTimingOut: true,
        timeoutSpanInMs: payload.autoLogoutInMs - payload.timeoutWarningInMs,
    })), on(onSessionExtended, signOutRedirect, (state) => ({
        ...state,
        isTimingOut: false,
        timeoutSpanInMs: undefined,
    })))
});

const IDLE_CONFIG = new InjectionToken('idle-config');

const getIsTimingOut = idleFeature.selectIsTimingOut;
const getTimeoutSpanInMs = idleFeature.selectTimeoutSpanInMs;
const selectLoggedInAndIsNotTimingOut = createSelector(oidcFeature.selectIsLoggedIn, idleFeature.selectIsTimingOut, (isLoggedIn, IsTimingOut) => isLoggedIn && !IsTimingOut);
const idleQuery = { getIsTimingOut, getTimeoutSpanInMs, selectLoggedInAndIsNotTimingOut };

class IdleEffects {
    getLoggedInActionPipe() {
        return this.actions$.pipe(switchMap(() => this.store.select(idleQuery.selectLoggedInAndIsNotTimingOut).pipe(filter((val) => val))));
    }
    constructor(idleConfig, store, actions$) {
        this.idleConfig = idleConfig;
        this.store = store;
        this.actions$ = actions$;
        this.signOutRedirect$ = createEffect(() => {
            return this.getLoggedInActionPipe().pipe(switchMap(() => timer(this.idleConfig.autoLogoutInMs)), map(() => signOutRedirect()));
        });
        this.timingOut$ = createEffect(() => {
            return this.getLoggedInActionPipe().pipe(switchMap(() => timer(this.idleConfig.timeoutWarningInMs)), map(() => onSessionTimingOut(this.idleConfig)));
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleEffects, deps: [{ token: IDLE_CONFIG }, { token: i1.Store }, { token: i2.Actions }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleEffects }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleEffects, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [IDLE_CONFIG]
                }] }, { type: i1.Store }, { type: i2.Actions }]; } });

class IdleFacade {
    constructor(store) {
        this.store = store;
        this.isTimingOut$ = this.store.select(idleQuery.getIsTimingOut);
        this.timeOutSpanInMs$ = this.store.select(idleQuery.getTimeoutSpanInMs);
    }
    extendSession() {
        this.store.dispatch(onSessionExtended());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleFacade, deps: [{ token: i1.Store }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleFacade, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleFacade, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: i1.Store }]; } });

class IdleWarningComponent {
    constructor(idleFacade) {
        this.idleFacade = idleFacade;
        this.isSessionTimingOut$ = new BehaviorSubject(false);
    }
    ngOnInit() {
        let timeOutSpan = 0;
        const msInSec = 1000;
        this.timeoutSub = this.idleFacade.isTimingOut$
            .pipe(tap((value) => this.isSessionTimingOut$.next(value)))
            .subscribe();
        this.secondsRemaining$ = this.idleFacade.timeOutSpanInMs$.pipe(filter((t) => (t || 0) > 0), tap((t) => (timeOutSpan = t)), switchMap(() => interval(msInSec)), map(() => Math.floor(timeOutSpan / msInSec)), tap(() => (timeOutSpan -= msInSec)));
    }
    ngOnDestroy() {
        this.timeoutSub?.unsubscribe();
    }
    close() {
        this.isSessionTimingOut$.next(false);
    }
    extend() {
        this.idleFacade.extendSession();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleWarningComponent, deps: [{ token: IdleFacade }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.1", type: IdleWarningComponent, selector: "imng-idle-warning", ngImport: i0, template: `<kendo-dialog
    title="Idle Session Warning"
    *ngIf="isSessionTimingOut$ | async"
    (close)="close()"
    [minWidth]="250"
    [width]="450"
  >
    <p class="warn-msg">Do you wish to extend your session?</p>
    <p class="warn-msg">{{ secondsRemaining$ | async }} Seconds remaining</p>
    <kendo-dialog-actions>
      <button kendoButton (click)="close()">No</button>
      <button kendoButton (click)="extend()" [primary]="true">Yes</button>
    </kendo-dialog-actions>
  </kendo-dialog> `, isInline: true, styles: [".warn-msg{margin:30px;text-align:center}\n"], dependencies: [{ kind: "directive", type: i2$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i3.DialogComponent, selector: "kendo-dialog", inputs: ["actions", "actionsLayout", "autoFocusedElement", "title", "width", "minWidth", "maxWidth", "height", "minHeight", "maxHeight", "animation", "themeColor"], outputs: ["action", "close"], exportAs: ["kendoDialog"] }, { kind: "component", type: i3.DialogActionsComponent, selector: "kendo-dialog-actions", inputs: ["actions", "layout"], outputs: ["action"] }, { kind: "component", type: i4.ButtonComponent, selector: "button[kendoButton], span[kendoButton], kendo-button", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "role", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "pipe", type: i2$1.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: IdleWarningComponent, decorators: [{
            type: Component,
            args: [{ selector: 'imng-idle-warning', template: `<kendo-dialog
    title="Idle Session Warning"
    *ngIf="isSessionTimingOut$ | async"
    (close)="close()"
    [minWidth]="250"
    [width]="450"
  >
    <p class="warn-msg">Do you wish to extend your session?</p>
    <p class="warn-msg">{{ secondsRemaining$ | async }} Seconds remaining</p>
    <kendo-dialog-actions>
      <button kendoButton (click)="close()">No</button>
      <button kendoButton (click)="extend()" [primary]="true">Yes</button>
    </kendo-dialog-actions>
  </kendo-dialog> `, styles: [".warn-msg{margin:30px;text-align:center}\n"] }]
        }], ctorParameters: function () { return [{ type: IdleFacade }]; } });

class ImngNgrxIdleModule {
    static forRoot(idleConfig) {
        return {
            ngModule: ImngNgrxIdleModule,
            providers: [
                { provide: IDLE_CONFIG, useValue: idleConfig },
                IdleFacade
            ]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: ImngNgrxIdleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.1", ngImport: i0, type: ImngNgrxIdleModule, declarations: [IdleWarningComponent], imports: [CommonModule, i1.StoreFeatureModule, i2.EffectsFeatureModule, DialogModule, ButtonsModule], exports: [IdleWarningComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: ImngNgrxIdleModule, imports: [CommonModule,
            StoreModule.forFeature(idleFeature),
            EffectsModule.forFeature([IdleEffects]),
            DialogModule, ButtonsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.1", ngImport: i0, type: ImngNgrxIdleModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        StoreModule.forFeature(idleFeature),
                        EffectsModule.forFeature([IdleEffects]),
                        DialogModule, ButtonsModule
                    ],
                    declarations: [IdleWarningComponent],
                    exports: [IdleWarningComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { IDLE_FEATURE_KEY, IdleFacade, IdleWarningComponent, ImngNgrxIdleModule, idleFeature, initialState };
//# sourceMappingURL=imng-kendo-ngrx-idle.mjs.map
